From 610aec8af11551793422a3fdc19912201ab455bf Mon Sep 17 00:00:00 2001
From: sandeepsajan0 <sandeepsajan0@gmail.com>
Date: Wed, 14 Sep 2022 10:35:35 +0530
Subject: [PATCH] Rename Screening Status to Screening Decision

---
 hypha/apply/activity/adapters/activity_feed.py  |  2 +-
 .../apply/api/v1/screening/tests/test_views.py  |  6 +++---
 hypha/apply/api/v1/screening/views.py           |  6 +++---
 hypha/apply/funds/forms.py                      |  5 ++++-
 .../0103_alter_screeningstatus_options.py       | 17 +++++++++++++++++
 hypha/apply/funds/models/screening.py           |  5 +++--
 .../funds/includes/screening_form.html          |  4 ++--
 .../funds/includes/screening_status_block.html  |  4 ++--
 .../funds/templates/funds/tables/table.html     |  2 +-
 hypha/apply/funds/tests/test_forms.py           |  2 +-
 hypha/apply/funds/tests/test_views.py           | 14 +++++++-------
 hypha/apply/funds/utils.py                      |  8 ++++----
 hypha/locale/django.pot                         |  8 ++++----
 hypha/locale/en/LC_MESSAGES/django.po           |  8 ++++----
 .../app/src/containers/ScreeningStatus/index.js |  2 +-
 .../tests/__snapshots__/index.test.js.snap      | 10 +++++-----
 .../ScreeningStatus/tests/action.test.js        |  4 ++--
 .../ScreeningStatus/tests/index.test.js         |  8 ++++----
 .../ScreeningStatus/tests/reducer.test.js       |  4 ++--
 .../ScreeningStatus/tests/saga.test.js          |  6 +++---
 .../ScreeningStatus/tests/selectors.test.js     |  6 +++---
 .../src/javascript/apply/screening-status.js    |  4 ++--
 22 files changed, 78 insertions(+), 57 deletions(-)
 create mode 100644 hypha/apply/funds/migrations/0103_alter_screeningstatus_options.py

diff --git a/hypha/apply/activity/adapters/activity_feed.py b/hypha/apply/activity/adapters/activity_feed.py
index cd35835a6..a109a3310 100644
--- a/hypha/apply/activity/adapters/activity_feed.py
+++ b/hypha/apply/activity/adapters/activity_feed.py
@@ -215,6 +215,6 @@ class ActivityAdapter(AdapterBase):
 
     def handle_screening_statuses(self, source, old_status, **kwargs):
         new_status = ', '.join([s.title for s in source.screening_statuses.all()])
-        return _('Screening status from {old_status} to {new_status}').format(
+        return _('Screening decision from {old_status} to {new_status}').format(
             old_status=old_status, new_status=new_status
         )
diff --git a/hypha/apply/api/v1/screening/tests/test_views.py b/hypha/apply/api/v1/screening/tests/test_views.py
index 33c1e1ae1..719e21340 100644
--- a/hypha/apply/api/v1/screening/tests/test_views.py
+++ b/hypha/apply/api/v1/screening/tests/test_views.py
@@ -101,7 +101,7 @@ class SubmissionScreeningStatusViewSetTests(APITestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
         self.assertEqual(
             response.json()['detail'],
-            "Can't set screening status without default being set"
+            "Can't set screening decision without default being set"
         )
 
     def test_cant_add_two_types_of_screening_status(self):
@@ -116,7 +116,7 @@ class SubmissionScreeningStatusViewSetTests(APITestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
         self.assertEqual(
             response.json()['detail'],
-            "Can't set screening status for both yes and no"
+            "Can't set screening decision for both yes and no"
         )
 
     def test_add_screening_status(self):
@@ -216,7 +216,7 @@ class SubmissionScreeningStatusViewSetTests(APITestCase):
         self.assertEqual(response.status_code, status.HTTP_400_BAD_REQUEST)
         self.assertEqual(
             response.json()['detail'],
-            "Can't delete default screening status."
+            "Can't delete default screening decision."
         )
 
     def test_cant_remove_not_set_screening_status(self):
diff --git a/hypha/apply/api/v1/screening/views.py b/hypha/apply/api/v1/screening/views.py
index 2eb3062ee..4e81ad948 100644
--- a/hypha/apply/api/v1/screening/views.py
+++ b/hypha/apply/api/v1/screening/views.py
@@ -52,12 +52,12 @@ class SubmissionScreeningStatusViewSet(
             ScreeningStatus, id=ser.validated_data['id']
         )
         if not submission.screening_statuses.filter(default=True).exists():
-            raise ValidationError({'detail': "Can't set screening status without default being set"})
+            raise ValidationError({'detail': "Can't set screening decision without default being set"})
         if (
             submission.screening_statuses.exists() and
             submission.screening_statuses.first().yes != screening_status.yes
         ):
-            raise ValidationError({'detail': "Can't set screening status for both yes and no"})
+            raise ValidationError({'detail': "Can't set screening decision for both yes and no"})
         submission.screening_statuses.add(
             screening_status
         )
@@ -84,7 +84,7 @@ class SubmissionScreeningStatusViewSet(
         screening_status = self.get_object()
         if screening_status.default:
             raise ValidationError({
-                'detail': "Can't delete default screening status."
+                'detail': "Can't delete default screening decision."
             })
         submission = self.get_submission_object()
         submission.screening_statuses.remove(screening_status)
diff --git a/hypha/apply/funds/forms.py b/hypha/apply/funds/forms.py
index ed2801430..c0e709af8 100644
--- a/hypha/apply/funds/forms.py
+++ b/hypha/apply/funds/forms.py
@@ -104,6 +104,9 @@ class ScreeningSubmissionForm(ApplicationSubmissionModelForm):
     class Meta:
         model = ApplicationSubmission
         fields = ('screening_statuses',)
+        labels = {
+            "screening_statuses": "Screening Decisions"
+        }
 
     def __init__(self, *args, **kwargs):
         self.user = kwargs.pop('user')
@@ -123,7 +126,7 @@ class ScreeningSubmissionForm(ApplicationSubmissionModelForm):
         instance = self.instance
         default_status = instance.screening_statuses.get(default=True)
         if default_status not in cleaned_data['screening_statuses']:
-            self.add_error('screening_statuses', 'Can\'t remove default screening status.')
+            self.add_error('screening_statuses', 'Can\'t remove default screening decision.')
         return cleaned_data
 
 
diff --git a/hypha/apply/funds/migrations/0103_alter_screeningstatus_options.py b/hypha/apply/funds/migrations/0103_alter_screeningstatus_options.py
new file mode 100644
index 000000000..b13b2cda8
--- /dev/null
+++ b/hypha/apply/funds/migrations/0103_alter_screeningstatus_options.py
@@ -0,0 +1,17 @@
+# Generated by Django 3.2.15 on 2022-09-13 13:15
+
+from django.db import migrations
+
+
+class Migration(migrations.Migration):
+
+    dependencies = [
+        ('funds', '0102_add_projectapprovalform_to_fundbase_labbase'),
+    ]
+
+    operations = [
+        migrations.AlterModelOptions(
+            name='screeningstatus',
+            options={'verbose_name': 'Screening Decision', 'verbose_name_plural': 'screening decisions'},
+        ),
+    ]
diff --git a/hypha/apply/funds/models/screening.py b/hypha/apply/funds/models/screening.py
index 083cc3d92..8f3b60677 100644
--- a/hypha/apply/funds/models/screening.py
+++ b/hypha/apply/funds/models/screening.py
@@ -12,13 +12,14 @@ class ScreeningStatus(models.Model):
     )
     default = models.BooleanField(
         default=False, verbose_name=_('Default Yes/No'),
-        help_text=_('Only one Yes and No screening status can be set as default.')
+        help_text=_('Only one Yes and No screening decision can be set as default.')
     )
 
     base_form_class = ScreeningStatusAdminForm
 
     class Meta:
-        verbose_name_plural = "screening statuses"
+        verbose_name = "Screening Decision"
+        verbose_name_plural = "screening decisions"
 
     def __str__(self):
         return self.title
diff --git a/hypha/apply/funds/templates/funds/includes/screening_form.html b/hypha/apply/funds/templates/funds/includes/screening_form.html
index 2e6210672..8772e2036 100644
--- a/hypha/apply/funds/templates/funds/includes/screening_form.html
+++ b/hypha/apply/funds/templates/funds/includes/screening_form.html
@@ -2,8 +2,8 @@
 {% if screening_form.should_show %}
 <div class="modal" id="screen-application" data-yes-statuses="{{ submission.yes_screening_statuses }}" data-no-statuses="{{ submission.no_screening_statuses }}" data-default-yes="{{ default_yes }}" data-default-no="{{ default_no }}">
     <h4 class="modal__header-bar">{% trans "Screen application" %}</h4>
-    <p id="current-status">{% trans "Current statuses" %}: {{ submission.screening_statuses.all|join:', ' }}</p>
-    {% trans "Screen" as screen %}
+    <p id="current-status">{% trans "Current decisions" %}: {{ submission.screening_statuses.all|join:', ' }}</p>
+    {% trans "Screening" as screen %}
     {% include 'funds/includes/delegated_form_base.html' with form=screening_form value=screen %}
 </div>
 {% endif %}
diff --git a/hypha/apply/funds/templates/funds/includes/screening_status_block.html b/hypha/apply/funds/templates/funds/includes/screening_status_block.html
index 11f21f5a6..585a4e3c4 100644
--- a/hypha/apply/funds/templates/funds/includes/screening_status_block.html
+++ b/hypha/apply/funds/templates/funds/includes/screening_status_block.html
@@ -1,7 +1,7 @@
 {% load i18n %}
 <div class="sidebar__inner">
 
-    <h5>{% trans "Screening status" %}</h5>
+    <h5>{% trans "Screening Decision" %}</h5>
     {% if object.supports_default_screening %}
         <div class="sidebar__screening-thumbs screening-status-box">
             <div class="sidebar__screening-status-yes">
@@ -43,7 +43,7 @@
                             <span class="sidebar__screening-option">{{ status }}</span>
                     {% endfor%}
                 </div>
-            </p>                
+            </p>
         {% endif %}
     </div>
 </div>
diff --git a/hypha/apply/funds/templates/funds/tables/table.html b/hypha/apply/funds/templates/funds/tables/table.html
index e10f1b4e9..c61fdd71b 100644
--- a/hypha/apply/funds/templates/funds/tables/table.html
+++ b/hypha/apply/funds/templates/funds/tables/table.html
@@ -20,7 +20,7 @@
                     <tr class="submission-meta__row">
                         <th><h6 class="heading heading--normal heading--no-margin">{% trans "Applicant" %}</h6></th>
                         <th><h6 class="heading heading--normal heading--no-margin">{% trans "Last updated" %}</h6></th>
-                        <th><h6 class="heading heading--normal heading--no-margin">{% trans "Screening statuses" %}</h6></th>
+                        <th><h6 class="heading heading--normal heading--no-margin">{% trans "Screening Decisions" %}</h6></th>
                         <th><h6 class="heading heading--normal heading--no-margin">{% trans "Review outcomes" %}</h6></th>
                     </tr>
                     <tr class="submission-meta__row submission-meta__row--black">
diff --git a/hypha/apply/funds/tests/test_forms.py b/hypha/apply/funds/tests/test_forms.py
index c2ac250cf..b2d0d0b40 100644
--- a/hypha/apply/funds/tests/test_forms.py
+++ b/hypha/apply/funds/tests/test_forms.py
@@ -28,7 +28,7 @@ class TestReviewerFormQueries(TestCase):
         # Meta categories
         # Assigned Reviewers
         # Roles
-        # Screening status
+        # Screening decision
         with self.assertNumQueries(6):
             form = UpdateReviewersForm(user=user, instance=submission)
 
diff --git a/hypha/apply/funds/utils.py b/hypha/apply/funds/utils.py
index 97a739629..8c3ebaf48 100644
--- a/hypha/apply/funds/utils.py
+++ b/hypha/apply/funds/utils.py
@@ -14,10 +14,10 @@ def render_icon(image):
 
 def get_default_screening_statues():
     """
-    Get the default screening statuses set.
+    Get the default screening decisions set.
 
     If the default for yes and no doesn't exit. First yes and
-    first no screening statuses created should be set as default
+    first no screening decisions created should be set as default
     """
     yes_screening_statuses = ScreeningStatus.objects.filter(yes=True)
     no_screening_statuses = ScreeningStatus.objects.filter(yes=False)
@@ -27,7 +27,7 @@ def get_default_screening_statues():
         try:
             default_yes = yes_screening_statuses.get(default=True)
         except ScreeningStatus.DoesNotExist:
-            # Set first yes screening status as default
+            # Set first yes screening decision as default
             default_yes = yes_screening_statuses.first()
             default_yes.default = True
             default_yes.save()
@@ -35,7 +35,7 @@ def get_default_screening_statues():
         try:
             default_no = no_screening_statuses.get(default=True)
         except ScreeningStatus.DoesNotExist:
-            # Set first no screening status as default
+            # Set first no screening decision as default
             default_no = no_screening_statuses.first()
             default_no.default = True
             default_no.save()
diff --git a/hypha/locale/django.pot b/hypha/locale/django.pot
index 7e55b9e50..c02bafe1c 100644
--- a/hypha/locale/django.pot
+++ b/hypha/locale/django.pot
@@ -156,7 +156,7 @@ msgstr ""
 
 #: hypha/apply/activity/adapters/activity_feed.py:218
 #, python-brace-format
-msgid "Screening status from {old_status} to {new_status}"
+msgid "Screening decision from {old_status} to {new_status}"
 msgstr ""
 
 #: hypha/apply/activity/adapters/django_messages.py:17
@@ -1825,7 +1825,7 @@ msgid "Default Yes/No"
 msgstr ""
 
 #: hypha/apply/funds/models/screening.py:15
-msgid "Only one Yes and No screening status can be set as default."
+msgid "Only one Yes and No screening decision can be set as default."
 msgstr ""
 
 #: hypha/apply/funds/models/submissions.py:485
@@ -2373,7 +2373,7 @@ msgid "Screen"
 msgstr ""
 
 #: hypha/apply/funds/templates/funds/includes/screening_status_block.html:4
-msgid "Screening status"
+msgid "Screening decision"
 msgstr ""
 
 #: hypha/apply/funds/templates/funds/includes/screening_status_block.html:36
@@ -2618,7 +2618,7 @@ msgid "Applicant"
 msgstr ""
 
 #: hypha/apply/funds/templates/funds/tables/table.html:23
-msgid "Screening statuses"
+msgid "Screening decisions"
 msgstr ""
 
 #: hypha/apply/funds/templates/funds/tables/table.html:24
diff --git a/hypha/locale/en/LC_MESSAGES/django.po b/hypha/locale/en/LC_MESSAGES/django.po
index 57429c89a..23cda5f66 100644
--- a/hypha/locale/en/LC_MESSAGES/django.po
+++ b/hypha/locale/en/LC_MESSAGES/django.po
@@ -156,7 +156,7 @@ msgstr ""
 
 #: hypha/apply/activity/adapters/activity_feed.py:218
 #, python-brace-format
-msgid "Screening status from {old_status} to {new_status}"
+msgid "Screening decision from {old_status} to {new_status}"
 msgstr ""
 
 #: hypha/apply/activity/adapters/django_messages.py:17
@@ -1825,7 +1825,7 @@ msgid "Default Yes/No"
 msgstr ""
 
 #: hypha/apply/funds/models/screening.py:15
-msgid "Only one Yes and No screening status can be set as default."
+msgid "Only one Yes and No screening decision can be set as default."
 msgstr ""
 
 #: hypha/apply/funds/models/submissions.py:485
@@ -2373,7 +2373,7 @@ msgid "Screen"
 msgstr ""
 
 #: hypha/apply/funds/templates/funds/includes/screening_status_block.html:4
-msgid "Screening status"
+msgid "Screening decision"
 msgstr ""
 
 #: hypha/apply/funds/templates/funds/includes/screening_status_block.html:36
@@ -2618,7 +2618,7 @@ msgid "Applicant"
 msgstr ""
 
 #: hypha/apply/funds/templates/funds/tables/table.html:23
-msgid "Screening statuses"
+msgid "Screening decisions"
 msgstr ""
 
 #: hypha/apply/funds/templates/funds/tables/table.html:24
diff --git a/hypha/static_src/src/app/src/containers/ScreeningStatus/index.js b/hypha/static_src/src/app/src/containers/ScreeningStatus/index.js
index c2621b364..857af3698 100644
--- a/hypha/static_src/src/app/src/containers/ScreeningStatus/index.js
+++ b/hypha/static_src/src/app/src/containers/ScreeningStatus/index.js
@@ -99,7 +99,7 @@ export class ScreeningStatusContainer extends React.PureComponent {
             const defaultSelectedId = screeningInfo.defaultSelectedValue &&
       screeningInfo.defaultSelectedValue.id;
             return (
-                <SidebarBlock title="Screening Status" >
+                <SidebarBlock title="Screening Decision" >
                     <div className="screening-status-box" style={{padding: '1rem'}}>
                         <div className="screening-default-options" >
                             <div
diff --git a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/__snapshots__/index.test.js.snap b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/__snapshots__/index.test.js.snap
index 356af9603..911a9d90c 100644
--- a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/__snapshots__/index.test.js.snap
+++ b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/__snapshots__/index.test.js.snap
@@ -1,6 +1,6 @@
 // Jest Snapshot v1, https://goo.gl/fbAQLP
 
-exports[`Test screening status Container Should render screening statuses with Sidebarblock 1`] = `
+exports[`Test screening decision Container Should render screening decisions with Sidebarblock 1`] = `
 <ScreeningStatusContainer
   defaultOptions={
     Object {
@@ -50,13 +50,13 @@ exports[`Test screening status Container Should render screening statuses with S
   }
 >
   <SidebarBlock
-    title="Screening Status"
+    title="Screening Decision"
   >
     <div
       className="sidebar-block"
     >
       <h5>
-        Screening Status
+        Screening Decision
       </h5>
       <div
         className="screening-status-box"
@@ -513,7 +513,7 @@ exports[`Test screening status Container Should render screening statuses with S
 </ScreeningStatusContainer>
 `;
 
-exports[`Test screening status Container Should render screening statuses with loading 1`] = `
+exports[`Test screening decision Container Should render screening decisions with loading 1`] = `
 <ScreeningStatusContainer
   allScreeningStatuses={null}
   screeningInfo={
@@ -668,7 +668,7 @@ exports[`Test screening status Container Should render screening statuses with l
 </ScreeningStatusContainer>
 `;
 
-exports[`Test screening status Container Should render screening statuses with loading false & defaultoptions empty 1`] = `
+exports[`Test screening decision Container Should render screening decisions with loading false & defaultoptions empty 1`] = `
 <ScreeningStatusContainer
   defaultOptions={Object {}}
   screeningInfo={
diff --git a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/action.test.js b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/action.test.js
index 5bae4af63..490c8089c 100644
--- a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/action.test.js
+++ b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/action.test.js
@@ -2,8 +2,8 @@ import * as actions from '../actions';
 import * as ActionTypes from '../constants';
 import Reducer from '../reducer';
 
-describe('Test actions of screening status', () => {
-    it('should return the screening statuses success action type', () => {
+describe('Test actions of screening decision', () => {
+    it('should return the screening decisions success action type', () => {
         const data = Reducer(undefined, {}).screeningStatuses;
         const expectedResult = {
             type: ActionTypes.GET_SCREENING_STATUSES,
diff --git a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/index.test.js b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/index.test.js
index abd352ad1..9f6edf650 100644
--- a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/index.test.js
+++ b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/index.test.js
@@ -7,8 +7,8 @@ import {SidebarBlock} from '@components/SidebarBlock';
 import LoadingPanel from '@components/LoadingPanel';
 enzyme.configure({adapter: new Adapter()});
 
-describe('Test screening status Container', () => {
-    it('Should render screening statuses with loading', () => {
+describe('Test screening decision Container', () => {
+    it('Should render screening decisions with loading', () => {
         const wrapper = mount(
             <ScreeningStatusContainer
                 screeningInfo={{loading: true}}
@@ -21,7 +21,7 @@ describe('Test screening status Container', () => {
         expect(wrapper).toMatchSnapshot();
     });
 
-    it('Should render screening statuses with loading false & defaultoptions empty', () => {
+    it('Should render screening decisions with loading false & defaultoptions empty', () => {
         const defaultOptions = {};
         const wrapper = mount(
             <ScreeningStatusContainer
@@ -36,7 +36,7 @@ describe('Test screening status Container', () => {
         expect(wrapper).toMatchSnapshot();
     });
 
-    it('Should render screening statuses with Sidebarblock', () => {
+    it('Should render screening decisions with Sidebarblock', () => {
         const selectVisibleOption = jest.fn();
         const defaultOptions = {
             yes: {id: 1, title: 'a'},
diff --git a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/reducer.test.js b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/reducer.test.js
index 4d1cde6c4..a3da4fb67 100644
--- a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/reducer.test.js
+++ b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/reducer.test.js
@@ -2,7 +2,7 @@ import initialState from '../models';
 import Reducer from '../reducer';
 import * as Actions from '../actions';
 
-describe('test reducer of screening status', () => {
+describe('test reducer of screening decision', () => {
     it('test  we get the initial data for undefined value of state', () => {
         expect(Reducer(undefined, {})).toEqual(initialState);
     });
@@ -16,7 +16,7 @@ describe('test reducer of screening status', () => {
         const action = Actions.hideLoadingAction();
         expect(Reducer(initialState, action)).toEqual(expected);
     });
-    it('on screening statuses success', () => {
+    it('on screening decisions success', () => {
         const data = {id: 1};
         const expected = initialState.set('screeningStatuses', data);
         const action = Actions.setScreeningSuccessAction(data);
diff --git a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/saga.test.js b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/saga.test.js
index 33ac796dc..354604142 100644
--- a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/saga.test.js
+++ b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/saga.test.js
@@ -8,7 +8,7 @@ import homePageSaga from '../sagas';
 import * as ActionTypes from '../constants';
 
 
-describe('Test setDefaultValue in Screening status module', () => {
+describe('Test setDefaultValue in Screening decision module', () => {
 
     it('Should trigger correct action for SUCCESS status', () => {
         const id = 1;
@@ -69,7 +69,7 @@ describe('Test setDefaultValue in Screening status module', () => {
 
 });
 
-describe('Test setVisibleOption in Screening status module', () => {
+describe('Test setVisibleOption in Screening decision module', () => {
 
     it('Should trigger correct action for SUCCESS status', () => {
         const id = 1;
@@ -176,7 +176,7 @@ describe('Test setVisibleOption in Screening status module', () => {
 
 });
 
-describe('Test takeEvery in Screening status module', () => {
+describe('Test takeEvery in Screening decision module', () => {
 
     const genObject = homePageSaga();
 
diff --git a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/selectors.test.js b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/selectors.test.js
index 9e5f5f226..ef520eeeb 100644
--- a/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/selectors.test.js
+++ b/hypha/static_src/src/app/src/containers/ScreeningStatus/tests/selectors.test.js
@@ -2,11 +2,11 @@ import {selectScreeningInfo, selectScreeningStatuses, selectDefaultOptions, sele
 import initialState from '../models';
 
 
-describe('Test the selector of screening status', () => {
-    it('select screening state', () => {
+describe('Test the selector of screening decision', () => {
+    it('select screening decision', () => {
         expect(selectScreeningInfo(initialState)).toEqual(initialState);
     });
-    it('select screening Statuses', () => {
+    it('select screening Decisions', () => {
         expect(selectScreeningStatuses(initialState)).toEqual(initialState.screeningStatuses);
     });
     it('select default options', () => {
diff --git a/hypha/static_src/src/javascript/apply/screening-status.js b/hypha/static_src/src/javascript/apply/screening-status.js
index 7e0a71bc4..cc41aeb1f 100644
--- a/hypha/static_src/src/javascript/apply/screening-status.js
+++ b/hypha/static_src/src/javascript/apply/screening-status.js
@@ -48,7 +48,7 @@
         var $screeningStatuses = $screenApplication.find('#id_screening_statuses');
         $screeningStatuses = $screeningStatuses.empty();
         if (currentStatus === true) {
-            $('#current-status').text('Current statuses: ' + defaultYes);
+            $('#current-status').text('Current decisions: ' + defaultYes);
             $.each(yesStatuses, function (key, value) {
                 if (key === defaultYes) {
                     $screeningStatuses.append($('<option></option>')
@@ -63,7 +63,7 @@
             });
         }
         else {
-            $('#current-status').text('Current statuses: ' + defaultNo);
+            $('#current-status').text('Current decisions: ' + defaultNo);
             $.each(noStatuses, function (key, value) {
                 if (key === defaultNo) {
                     $screeningStatuses.append($('<option></option>')
diff --git a/hypha/apply/funds/tests/test_views.py b/hypha/apply/funds/tests/test_views.py
index 349d72e44..c9777fc3f 100644
--- a/hypha/apply/funds/tests/test_views.py
+++ b/hypha/apply/funds/tests/test_views.py
@@ -220,16 +220,16 @@ class TestStaffSubmissionView(BaseSubmissionViewTestCase):
         screening_outcome2.save()
         self.submission.screening_statuses.clear()
         response = self.get_page(self.submission)
-        self.assertContains(response, 'Screening status')
+        self.assertContains(response, 'Screening Decision')
 
     def test_cant_view_submission_screening_block(self):
         """
         If defaults are not set screening status block is not visible
         """
         ScreeningStatus.objects.all().delete()
         self.submission.screening_statuses.clear()
         response = self.get_page(self.submission)
-        self.assertNotContains(response, 'Screening status')
+        self.assertNotContains(response, 'Screening decision')
 
     def test_can_create_project(self):
         # check submission doesn't already have a Project
@@ -936,8 +936,8 @@ class TestApplicantSubmissionView(BaseSubmissionViewTestCase):
 
     def test_cant_screen_submission(self):
         """
-        Test that an applicant cannot set the screening status
-        and that they don't see the screening status form.
+        Test that an applicant cannot set the screening decision
+        and that they don't see the screening decision form.
         """
         screening_outcome = ScreeningStatusFactory()
         response = self.post_page(self.submission, {'form-submitted-screening_form': '', 'screening_statuses': [screening_outcome.id]})
@@ -947,7 +947,7 @@ class TestApplicantSubmissionView(BaseSubmissionViewTestCase):
 
     def test_cant_see_screening_status_block(self):
         response = self.get_page(self.submission)
-        self.assertNotContains(response, 'Screening status')
+        self.assertNotContains(response, 'Screening decision')
 
     def test_cant_see_add_determination_primary_action(self):
         def assert_add_determination_not_displayed(submission, button_text):
@@ -1279,7 +1279,7 @@ class TestSuperUserSubmissionView(BaseSubmissionViewTestCase):
         self.assertEqual(submission.screening_statuses.count(), 2)
 
         # Check that an activity was created that should only be viewable internally
-        activity = Activity.objects.filter(message__contains='Screening status').first()
+        activity = Activity.objects.filter(message__contains='Screening decision').first()
         self.assertEqual(activity.visibility, TEAM)
 
 
@@ -220,16 +220,16 @@ class TestStaffSubmissionView(BaseSubmissionViewTestCase):
     def test_cant_view_submission_screening_block(self):
         """
-        If defaults are not set screening status block is not visible
+        If defaults are not set screening decision block is not visible
         """
         ScreeningStatus.objects.all().delete()
-- 
GitLab